==> deepin-home_0.0.5.orig.tar.xz: deepin-home-0.0.5/translations/deepin-home/hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>Érkezik</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Communication</source>
        <translation>Kommunikáció</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Discuss and share here</source>
        <translation>Beszélgessenek és osszák meg itt</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="60"/>
        <source>Bug Report</source>
        <translation>Hibajelentés küldése</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Report issues you found</source>
        <translation>Jelentse a hibákat, amelyeket talál</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="68"/>
        <source>Suggestions</source>
        <translation>Javaslatok</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Submit your suggestions</source>
        <translation>Küldje be javaslatait</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="83"/>
        <source>Resources</source>
        <translation>Források</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="88"/>
        <source>Questionaire</source>
        <translation>Kérdőív</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="145"/>
        <source>Join US</source>
        <translation>Csatlakozzon hozzánk</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="150"/>
        <source>Internal Testing</source>
        <translation>Belső tesztelés</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="163"/>
        <source>Community News</source>
        <translation>Közösségi Hírek</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>Üzenetek</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>Kérdőívek</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="25"/>
        <source>About</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="29"/>
        <source>Exit</source>
        <translation>kilépés</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="39"/>
        <source>Version: %1</source>
        <translation>Verzió: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="40"/>
        <source>Deepin Messages</source>
        <translation>Deepin® Üzenetek</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="76"/>
        <source>Unlogged</source>
        <translation>Nincs bejelentkezve</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="111"/>
        <source>Sign in</source>
        <translation>Bejelentkezés</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="123"/>
        <source>Sign out</source>
        <translation>Kijelentkezés</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>Nincsenek üzenetek</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="148"/>
        <source>%1 messages</source>
        <translation>%1 üzenet</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="152"/>
        <source>Mark all as read</source>
        <translation>Összes megjelölése olvasottként</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>Továbbiak megtekintése</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>Nincsenek kérdőívek.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="88"/>
        <source>Expired on: %1</source>
        <translation>Kitöltési idő: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="116"/>
        <source>Fill In</source>
        <translation>Kitöltés</translation>
    </message>
</context>
</TS>

==> deepin-home_1.0.13.orig.tar.xz: deepin-home-1.0.13/translations/deepin-home/hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>Érkezik</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Communication</source>
        <translation>Kommunikáció</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Discuss and share here</source>
        <translation>Beszélgessenek és osszák meg itt</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="60"/>
        <source>Bug Report</source>
        <translation>Hibajelentés küldése</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Report issues you found</source>
        <translation>Jelentse a hibákat, amelyeket talál</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="68"/>
        <source>Suggestions</source>
        <translation>Javaslatok</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Submit your suggestions</source>
        <translation>Küldje be javaslatait</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="83"/>
        <source>Resources</source>
        <translation>Források</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="88"/>
        <source>Questionaire</source>
        <translation>Kérdőív</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="145"/>
        <source>Join US</source>
        <translation>Csatlakozzon hozzánk</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="150"/>
        <source>Internal Testing</source>
        <translation>Belső tesztelés</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="163"/>
        <source>Community News</source>
        <translation>Közösségi Hírek</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="278"/>
        <source>Network error, please try later</source>
        <translation>Hálózati hiba, próbálja meg később</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>Üzenetek</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>Kérdőívek</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="26"/>
        <source>Launch at system startup</source>
        <translation>Indítsa el a rendszer indításakor</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="32"/>
        <source>About</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="36"/>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="46"/>
        <source>Version: %1</source>
        <translation>Verzió: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="47"/>
        <source>Deepin Messages</source>
        <translation>Deepin® Üzenetek</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="83"/>
        <source>Unlogged</source>
        <translation>Nincs bejelentkezve</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="118"/>
        <source>Sign in</source>
        <translation>Bejelentkezés</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="130"/>
        <source>Sign out</source>
        <translation>Kijelentkezés</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>Nincsenek üzenetek</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="148"/>
        <source>%1 messages</source>
        <translation>%1 üzenet</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="152"/>
        <source>Mark all as read</source>
        <translation>Összes megjelölése olvasottként</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>Továbbiak megtekintése</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>Nincsenek kérdőívek.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="88"/>
        <source>Expired on: %1</source>
        <translation>Kitöltési idő: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="116"/>
        <source>Fill In</source>
        <translation>Kitöltés</translation>
    </message>
</context>
</TS>
